SubroutineUniforms
******************

.. currentmodule:: ModernGL

.. autoclass:: SubroutineUniform
	:members: name, location

.. autoclass:: SubroutineUniformMap

	.. automethod:: __getitem__(key) -> SubroutineUniform

.. toctree::
	:maxdepth: 4
